/*
littleBits Arduino Module
Matt Richard
Feb-09-2014

_Analog Read Controls Analog Output_

What is supposed to happen:
This sketch causes an output module connected to pin 5 to "breathe", growing and shrinking.
The "breathe" timing is based on the value of an analog input module connected to pin A0.
The "breathing" of an output module is produced by using Pulse Width Modulation (PWM).
PWM quickly switches the power between on and off so fast that we percieve it to be
some percentage of on or off. PWM is essential in all modern LED displays including
those in Times Square.


This sketch includs the following commands:
pinMode( pin, mode );       pin = a digital pin, mode = OUTPUT or INPUT
for(init, test, update);    init = initialize variable for use in confirming validity of test
                            test = a logic statement to determine if the for loop is complete
                            update = init variable is updated, this effects whether the test is TRUE or FALSE
analogWrite( pin, PWM value ); pin = a digital pin that has been set to OUTPUT, PWM value = 0 —— 255
delay( time );              time = time of delay in milliseconds
analogRead( pin );          pin = an analog pin
*/

void setup(){

  // since we are going to use pin 5 to control an output module
  // we need to set the pinMode of pin 5 to OUTPUT,
  // this means voltage will flow out of the pin
  pinMode(5, OUTPUT); // set pin 5 to OUTPUT mode
  // techincally, this step is not necessary when using analogWrite instead of digitalWrite
  // but it cant hurt to include it and it reminds us that we want pin 5 as an output

}

void loop(){

  // This for loop will act as the inhale for the PWM value
  // starting at a value of zero and growing to a max value of 255
  for(int PWM_value = 0; PWM_value <= 255; PWM_value ++){

    analogWrite(5, PWM_value);
    delay( (1400 - analogRead(A0)) / 10 ); // wait for a moment before moving forward
  // use the analog input module to determine length of moment                     
  // The formula ( (1034 - analogRead(A0)) / 10 ) gives us a range of possible values from 1 —— 102
  }
  
  // This for loop will act as the exhale for the PWM value
  // starting at a value of 255 and shrinking to a min value of 0
  for(int PWM_value = 255; PWM_value >= 0; PWM_value --){

    analogWrite(5, PWM_value);
    delay( (1400 - analogRead(A0)) / 10 ); // wait for a moment before moving forward
  // use the analog input module to determine length of moment                     
  // The formula  ( (1034 - analogRead(A0)) / 10 ) gives us a range of possible values from 1——102
  }

}


